@@ -1,11 +1,5 @@
 MC.Xdc.statistics <-
-function(group.Nrs, numMC=10, alphap, type="ha", siglev=0.05, est="mom", MC=NULL, Nrs=NULL) {
-	# Check if someone is still using Nrs
-	if(!is.null(Nrs)){
-		warning("'Nrs' is deprecated. It has been replaced with group.Nrs. View the help files for details.")
-		group.Nrs <- Nrs
-	}
-	
+function(group.Nrs, numMC=10, alphap, type="ha", siglev=0.05, est="mom") {
 	if(missing(alphap) || missing(group.Nrs))
 		stop("group.Nrs and/or alphap  missing.")
 	if(tolower(type) != "ha" && tolower(type) != "hnull")
@@ -13,12 +7,6 @@ function(group.Nrs, numMC=10, alphap, type="ha", siglev=0.05, est="mom", MC=NULL
 	if(tolower(est) != "mom" && tolower(est) != "mle")
 		stop(sprintf("Est '%s' not found. Est must be 'mle' or 'mom'.", as.character(est)))
 	
-	# Check if someone is still using MC
-	if(!is.null(MC)){
-		warning("'MC' is deprecated. It has been replaced with numMC. View the help files for details.")
-		numMC <- MC
-	}
-	
 	numGroups <- length(group.Nrs)	
 	
 	if(tolower(type) == "hnull"){
