@@ -1,11 +1,5 @@
 MC.Xmcupo.statistics <-
-function(group.Nrs, numMC=10, pi0, group.pi, group.theta, type="ha", siglev=0.05, MC=NULL, Nrs=NULL) {
-	# Check if someone is still using Nrs
-	if(!is.null(Nrs)){
-		warning("'Nrs' is deprecated. It has been replaced with group.Nrs. View the help files for details.")
-		group.Nrs <- Nrs
-	}
-	
+function(group.Nrs, numMC=10, pi0, group.pi, group.theta, type="ha", siglev=0.05) {
 	if(missing(group.theta) || missing(group.Nrs))
 		stop("group.Nrs and/or group.theta missing.")
 	if(missing(group.pi) && tolower(type) == "ha")
@@ -15,12 +9,6 @@ function(group.Nrs, numMC=10, pi0, group.pi, group.theta, type="ha", siglev=0.05
 	if(tolower(type) != "ha" && tolower(type) != "hnull")
 		stop(sprintf("Type '%s' not found. Type must be 'ha' for power or 'hnull' for size.\n", as.character(type)))
 	
-	# Check if someone is still using MC
-	if(!is.null(MC)){
-		warning("'MC' is deprecated. It has been replaced with numMC. View the help files for details.")
-		numMC <- MC
-	}
-	
 	numGroups <- length(group.Nrs)
 	
 	# Create the parameters for every group
