@@ -1,16 +1,10 @@
 MC.ZT.statistics <-
-function(Nrs, numMC=10, fit, type="ha", siglev=0.05, MC=NULL) {
+function(Nrs, numMC=10, fit, type="ha", siglev=0.05) {
 	if(missing(Nrs) || missing(fit))
 		stop("Nrs and/or fit missing.")
 	if(tolower(type) != "ha" && tolower(type) != "hnull")
 		stop(sprintf("Type '%s' not found. Type must be 'ha' for power or 'hnull' for size.\n", as.character(type)))
 	
-	# Check if someone is still using MC
-	if(!is.null(MC)){
-		warning("'MC' is deprecated. It has been replaced with numMC. View the help files for details.")
-		numMC <- MC
-	}
-	
 	# Get all the ZT values
 	ZTstatMatrix <- matrix(0, numMC, 2)
 	for(i in 1:numMC)
