@@ -3,22 +3,25 @@ function(y, wt, x, parms, continuous){
 	# Get initial LL
 	LL <- DM.MoM(y)$loglik
 	
+	uniqX <- sort(unique(x))
+	numUni <- length(uniqX) - 1
+	
 	# Determine what we are comparing
 	if(continuous){
 		numTests <- length(x) - 1
 		dir <- rep(-1, numTests)
 	}else{
-		uniqX <- sort(unique(x))
-		numTests <- length(uniqX) - 1
+		numTests <- numUni
 		dir <- uniqX
 	}
 	
 	# Run through every comparison
 	LRT <- rep(0, numTests)
-	for(i in 1:numTests){
+	for(i in 1:numUni){
 		if(continuous){
-			grp1 <- y[1:i,, drop=FALSE]
-			grp2 <- y[-c(1:i),, drop=FALSE]
+			id <- which(x <= uniqX[i])
+			grp1 <- y[id,, drop=FALSE]
+			grp2 <- y[-id,, drop=FALSE]
 		}else{
 			grp1 <- y[x == uniqX[i],, drop=FALSE]
 			grp2 <- y[x != uniqX[i],, drop=FALSE]
@@ -34,7 +37,11 @@ function(y, wt, x, parms, continuous){
 		if(LLgrp1 == Inf || LLgrp2 == Inf)
 			next
 		
-		LRT[i] <- -2*(LL-LLgrp1-LLgrp2)
+		if(continuous){
+			LRT[id[length(id)]] <- -2*(LL-LLgrp1-LLgrp2)
+		}else{
+			LRT[i] <- -2*(LL-LLgrp1-LLgrp2)
+		}
 	}
 	ret <- list(goodness=LRT, direction=dir)
 	
